@@ -1,5 +1,5 @@
-#  tests for rmf-1.3-py39h428a9b3_3 (this is a generated file);
-print('===== testing package: rmf-1.3-py39h428a9b3_3 =====');
+#  tests for rmf-1.3.1-py39h428a9b3_0 (this is a generated file);
+print('===== testing package: rmf-1.3.1-py39h428a9b3_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import RMF
@@ -19,7 +19,7 @@ for suffix in ('rmf', 'rmf-hdf5'):
     os.unlink("test.%s" % suffix)
 #  --- run_test.py (end) ---
 
-print('===== rmf-1.3-py39h428a9b3_3 OK =====');
+print('===== rmf-1.3.1-py39h428a9b3_0 OK =====');
 print("import: 'RMF'")
 import RMF
 
